@@ -7,7 +7,7 @@
 **
 **  (c) 2000 Dr. Andreas Mueller
 **
-**  $Id: auth.c,v 1.15 2010/02/06 09:24:18 afm Exp $
+**  $Id: auth.c,v 1.16 2011/06/13 21:41:34 afm Exp $
 */ 
 #include "mod_authz_ldap.h"
 
@@ -173,16 +173,6 @@ int	authz_ldap_authenticate(authz_ldap_config_rec *sec, request_rec *r,
 		return HTTP_UNAUTHORIZED;
 	}
 
-	/* set LDAP version 3 protocol options				*/
-	if (LDAP_OPT_SUCCESS != ldap_set_option(ldap, LDAP_OPT_PROTOCOL_VERSION,
-		&version)) {
-		ap_log_rerror(APLOG_MARK, APLOG_NOERRNO|APLOG_ERR, 0, r,
-			"[%d] cannot set the protocol version", (int)getpid());
-	} else {
-		AUTHZ_RDEBUG("[%d] protocol version set to %d", (int)getpid(),
-			version);
-	}
-
 	/* check the password by binding against the directory		*/
 	res =ldap_simple_bind_s(ldap, dn, pw);
 	authz_ldap_unbind(sec, ldap);
