@@ -7,14 +7,24 @@
 **
 **  (c) 2000 Dr. Andreas Mueller
 **
-**  $Id: certmap.c,v 1.12 2010/02/06 09:55:03 afm Exp $
+**  $Id: certmap.c,v 1.13 2011/06/13 21:41:34 afm Exp $
 */ 
 #include "mod_authz_ldap.h"
 #include <openssl/pem.h>
 #include <openssl/x509v3.h>
 #ifdef AUTHZ_LDAP_HAVE_SSL
-extern char	*ssl_var_lookup(apr_pool_t *, server_rec *, conn_rec *,
-			request_rec *, char *);
+static char	*do_ssl_var_lookup(apr_pool_t *p, server_rec *s, conn_rec *c,
+			request_rec *r, char *v) {
+	APR_OPTIONAL_FN_TYPE(ssl_var_lookup) *lookupfn;
+
+	lookupfn = APR_RETRIEVE_OPTIONAL_FN(ssl_var_lookup);
+    
+	if (lookupfn) {
+		return lookupfn(p, s, c, r, v);
+	} else {
+		return NULL;
+	}
+}
 #else
 static int	sslwarningsent = 0;
 static void	sendsslwarning(request_rec *r) {
@@ -39,7 +49,7 @@ static char	*authz_ldap_get_issuer_dn(authz_ldap_config_rec *sec,
 #ifdef AUTHZ_LDAP_HAVE_SSL
 	char			*issuer_dn;
 
-	issuer_dn = ssl_var_lookup(r->pool, r->server, r->connection, r,
+	issuer_dn = do_ssl_var_lookup(r->pool, r->server, r->connection, r,
 		"SSL_CLIENT_I_DN");
 	AUTHZ_RDEBUG("[%d] client issuer DN: %s", (int)getpid(),
 		(issuer_dn) ? issuer_dn : "(null)");
@@ -60,7 +70,7 @@ static char	*authz_ldap_get_certificate(authz_ldap_config_rec *sec,
 	X509		*xs;
 
 	/* retrieve the certificate in PEM form				*/
-	xp = ssl_var_lookup(r->pool, r->server, r->connection, r,
+	xp = do_ssl_var_lookup(r->pool, r->server, r->connection, r,
 		"SSL_CLIENT_CERT");
 	if (NULL == xp) { 
 		AUTHZ_RDEBUG("[%d] not certificate found", (int)getpid());
@@ -108,7 +118,7 @@ static char	*authz_ldap_get_subject_dn(authz_ldap_config_rec *sec,
 #ifdef AUTHZ_LDAP_HAVE_SSL
 	char	*subject_dn;
 
-	subject_dn = ssl_var_lookup(r->pool, r->server, r->connection, r,
+	subject_dn = do_ssl_var_lookup(r->pool, r->server, r->connection, r,
 		"SSL_CLIENT_S_DN");
 	AUTHZ_RDEBUG("[%d] client subject DN: %s", (int)getpid(),
 		(subject_dn) ? subject_dn : "(null)");
@@ -125,7 +135,7 @@ static char	*authz_ldap_get_certserial(authz_ldap_config_rec *sec,
 	char	*cp;
 
 	/* get serial number from X509 client certificate		*/
-	cp = ssl_var_lookup(r->pool, r->server, r->connection, r,
+	cp = do_ssl_var_lookup(r->pool, r->server, r->connection, r,
 		"SSL_CLIENT_M_SERIAL");
 	AUTHZ_RDEBUG("[%d] client serial: %s", (int)getpid(),
 		(cp) ? cp : "(null)");
@@ -181,7 +191,7 @@ char	*authz_ldap_get_ms_x500_alt_security_identity(
 	X509_NAME	*name;
 
 	/* retrieve the certificate in PEM form				*/
-	xp = ssl_var_lookup(r->pool, r->server, r->connection, r,
+	xp = do_ssl_var_lookup(r->pool, r->server, r->connection, r,
 		"SSL_CLIENT_CERT");
 	if (NULL == xp) { 
 		AUTHZ_RDEBUG("[%d] not certificate found", (int)getpid());
@@ -268,7 +278,7 @@ char	*authz_ldap_get_ms_user_principal_name(authz_ldap_config_rec *sec,
 	ASN1_OBJECT	*upnoid;
 
 	/* retrieve the certificate in PEM form				*/
-	xp = ssl_var_lookup(r->pool, r->server, r->connection, r,
+	xp = do_ssl_var_lookup(r->pool, r->server, r->connection, r,
 		"SSL_CLIENT_CERT");
 	if (NULL == xp) { 
 		AUTHZ_RDEBUG("[%d] not certificate found", (int)getpid());
@@ -361,11 +371,12 @@ char	*authz_ldap_get_ms_user_principal_name(authz_ldap_config_rec *sec,
 /* utility function to escape parentheses in filter expressions */
 static void	authz_ldap_escape_parentheses(char *org, char *new) {
 	char	*p = org, *q = new;
-	while ((*p) && ((q - new) < MAX_STRING_LEN))
+	while ((*p) && ((q - new) < MAX_STRING_LEN)) {
 		if ((*p == '(') || (*p == ')')) {
 			*q++ = '\\';
-			*q++ = *p++;
 		}
+		*q++ = *p++;
+	}
 	*q = '\0';
 }
 
