@@ -3,7 +3,7 @@
  *
  * (c) 2001-2010 Prof. Dr. Andreas Mueller, Beratung und Entwicklung
  *
- * $Id: mod_authz_ldap.h,v 1.17 2010/02/06 09:24:18 afm Exp $
+ * $Id: mod_authz_ldap.h,v 1.19 2011/06/13 21:53:34 afm Exp $
  */
 #ifndef _MOD_AUTHZ_LDAP_H
 #define _MOD_AUTHZ_LDAP_H
@@ -26,6 +26,9 @@
 #ifdef HAVE_LDAP_H
 #include <ldap.h>
 #endif
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
 #ifdef HAVE_SYS_TIMES_H
 #include <sys/times.h>
 #endif
