@@ -7,7 +7,7 @@
 **
 **  (c) 2001 Dr. Andreas Mueller
 **
-**  $Id: modconf.c,v 1.13 2010/02/06 09:24:18 afm Exp $
+**  $Id: modconf.c,v 1.15 2011/06/13 21:53:34 afm Exp $
 */ 
 #include "mod_authz_ldap.h"
 
@@ -21,7 +21,7 @@ static const char	*authz_ldap_set_user_scope_slot(cmd_parms *parms,
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-	AUTHZ_DEBUG("setting user search scope at %x to '%s'", parms->server,
+	AUTHZ_DEBUG("setting user search scope at %p to '%s'", parms->server,
 		(void *)sec, (arg) ? arg : "(null)");
 	/* check for correct directives					*/
 	if (0 == strcasecmp("subtree", arg)) {
@@ -41,7 +41,7 @@ static const char	*authz_ldap_set_group_scope_slot(cmd_parms *parms,
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-	AUTHZ_DEBUG("setting group search scope at %x to '%s'", parms->server,
+	AUTHZ_DEBUG("setting group search scope at %p to '%s'", parms->server,
 		(void *)sec, (arg) ? arg : "(null)");
 	/* check for correct directives					*/
 	if (0 == strcasecmp("subtree", arg)) {
@@ -61,7 +61,7 @@ static const char	*authz_ldap_set_map_scope_slot(cmd_parms *parms,
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-	AUTHZ_DEBUG("setting map search scope at %x to '%s'", parms->server,
+	AUTHZ_DEBUG("setting map search scope at %p to '%s'", parms->server,
 		(void *)sec, (arg) ? arg : "(null)");
 	/* check for correct directives					*/
 	if (0 == strcasecmp("subtree", arg)) {
@@ -81,7 +81,7 @@ static const char	*authz_ldap_set_loglevel_slot(cmd_parms *parms,
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-	AUTHZ_DEBUG("setting loglevel at %x to '%s'",
+	AUTHZ_DEBUG("setting loglevel at %p to '%s'",
 		(void *)sec, (arg) ? arg : "(null)");
 	/* check for the various possible legal values of the argument	*/
 	if (0 == strcasecmp("emerg", arg)) {
@@ -116,7 +116,7 @@ static const char	*authz_ldap_set_version_slot(cmd_parms *parms,
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-	AUTHZ_DEBUG("setting ldap version at %x to '%s'", parms->server,
+	AUTHZ_DEBUG("setting ldap version at %p to '%s'", parms->server,
 		(void *)sec, (arg) ? arg : "(null)");
 
 	sec->ldapversion = atoi(arg);
@@ -134,7 +134,7 @@ static const char	*authz_ldap_set_method_slot(cmd_parms *parms,
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-	AUTHZ_DEBUG("setting auth method at %x to '%s'", parms->server,
+	AUTHZ_DEBUG("setting auth method at %p to '%s'", parms->server,
 		(void *)sec, (arg) ? arg : "(null)");
 
 	sec->method = AUTHMETHOD_NONE;
@@ -164,7 +164,7 @@ static const char	*authz_ldap_set_mapmethod_slot(cmd_parms *parms,
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-	AUTHZ_DEBUG("setting map method at %x to '%s'", parms->server,
+	AUTHZ_DEBUG("setting map method at %p to '%s'", parms->server,
 		(void *)sec, (arg) ? arg : "(null)");
 
 	sec->mapmethod = AUTHMAPMETHOD_NONE;
@@ -192,7 +192,7 @@ static const char	*authz_ldap_set_setauth_slot(cmd_parms *parms,
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-	AUTHZ_DEBUG("setting authoriziation header at %x to '%s'",
+	AUTHZ_DEBUG("setting authoriziation header at %p to '%s'",
 		parms->server, (void *)sec, (arg) ? arg : "(null)");
 
 	sec->setauth = AUTHHEADER_NONE;
@@ -224,7 +224,7 @@ static const char	*authz_ldap_set_setgroup_slot(cmd_parms *parms,
 	authz_ldap_config_rec   *sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 	
-	AUTHZ_DEBUG("setting group attribute at %x to '%s'", parms->server,
+	AUTHZ_DEBUG("setting group attribute at %p to '%s'", parms->server,
 		(void *)sec, (arg) ? arg : "(null)");
 
 	sec->setgroup = AUTHHEADER_USER;
